@@ -1,6 +1,3 @@
-from __future__ import print_function
-
-import sys
 from concurrent.futures import ThreadPoolExecutor
 from functools import partial
 from multiprocessing import Pool, RLock, freeze_support
@@ -12,13 +9,12 @@ from tqdm.auto import tqdm, trange
 from tqdm.contrib.concurrent import process_map, thread_map
 
 NUM_SUBITERS = 9
-PY2 = sys.version_info[:1] <= (2,)
 
 
 def progresser(n, auto_position=True, write_safe=False, blocking=True, progress=False):
-    interval = random() * 0.002 / (NUM_SUBITERS - n + 2)
+    interval = random() * 0.002 / (NUM_SUBITERS - n + 2)  # nosec
     total = 5000
-    text = "#{0}, est. {1:<04.2}s".format(n, interval * total)
+    text = f"#{n}, est. {interval * total:<04.2g}s"
     for _ in trange(total, desc=text, disable=not progress,
                     lock_args=None if blocking else (False,),
                     position=None if auto_position else n):
@@ -37,7 +33,7 @@ if __name__ == '__main__':
     L = list(range(NUM_SUBITERS))[::-1]
 
     print("Simple thread mapping")
-    thread_map(partial(progresser, write_safe=not PY2), L, max_workers=4)
+    thread_map(partial(progresser, write_safe=True), L, max_workers=4)
 
     print("Simple process mapping")
     process_map(partial(progresser), L, max_workers=4)
@@ -54,8 +50,5 @@ if __name__ == '__main__':
 
     print("Multi-threading")
     tqdm.set_lock(TRLock())
-    pool_args = {}
-    if not PY2:
-        pool_args.update(initializer=tqdm.set_lock, initargs=(tqdm.get_lock(),))
-    with ThreadPoolExecutor(**pool_args) as p:
-        p.map(partial(progresser, progress=True, write_safe=not PY2, blocking=False), L)
+    with ThreadPoolExecutor(initializer=tqdm.set_lock, initargs=(tqdm.get_lock(),)) as p:
+        p.map(partial(progresser, progress=True, write_safe=True, blocking=False), L)
